# NativeBase
The missing piece of React Native


![logo](/img/logo.png)

Get on the mobile fast track with NativeBase, the fastest-growing platform and tool set for iOS and Android development. Get an introduction to NativeBase and work through an instance application that highlights React Native programming techniques.


# Contents

-	[What is NativeBase?](#what-is-nativebase)
-	[Testimonials](#testimonials)
-	[Why NativeBase?](#why-nativebase)
-	[Magic of NativeBase](#magic-of-nativebase)
-	[Get Started](#get-started)
-	[Components](#components)
-	[Native Starter Kit](#native-starter-kit)
-	[Featured Apps - Native Starter Pro](#featured-apps---native-starter-pro)
-	[Quick Links to NativeBase](#quick-links-to-nativebase)
-	[Documentation](#documentation)
-	[Website](#website)



## What is NativeBase
[NativeBase](http://nativebase.io/) is a free and open source framework that enables developers to build high-quality mobile apps using [React Native](https://github.com/facebook/react-native) iOS and Android apps with a fusion of [ES6](http://es6-features.org/#Constants). NativeBase builds a layer on top of React Native that provides you with basic set of components for mobile application development. This helps you to build world-class application experiences on native platforms.


The applications stack of components is built using native UI components and because of that, there are no compromises with the User Experience of the applications. NativeBase is targeted specially on the look and feel, and UI interplay of your app. NativeBase without a doubt fits in well with mobile applications which cuts down one huge part of your app - The Front end.

What is really great is that you can use shared UI cross-platform components, which will drastically increase your productivity. When using NativeBase, you can use any native third-party libraries out of the box. You do not need to use wrappers or do any other actions. The new additions to the native platform are available immediately. NativeBase provides amazing support for adding components, so that you will by no means hit a lifeless stop. [Read More. . .](http://nativebase.io/documentation)

One import statement, and you get all NativeBase components.
```
import { list of Components } from 'native-base';
```



## Testimonials

Some quotes from users of **NativeBase**

**Recommended by** ![Microsoft](/img/microsoft-logo.png)
> If you're looking to get started with React Native + CodePush, and are looking for an awesome starter kit, you should check out Native Starter Pro - [Microsoft's react-native-code-push repo](https://github.com/Microsoft/react-native-code-push#example-apps--starters)

**Recommended by [Awesome React Native](https://github.com/jondot/awesome-react-native)**
>NativeBase added into the list of [Frameworks](https://github.com/jondot/awesome-react-native#frameworks) of Awesome React Native.

**vitalets**
>Thanks for such useful library.

**robtweed**
>The components look great, and I'd love to use them.

**chromakey**
>Thanks for a great library. I appreciate the quick fix!

**webinspired**
>Ran thru the demo.... it was amazing...

**mrphu3074**
>NativeBase is rapid my prototype.

**michshat**
>This framework looks really good - Thank you!

**Nickman87**
>I'm trying out your nativeBase package as it looks like it can simplify a lot of my views.

**RezaRahmati**
>Great library.



## Why NativeBase?
<center>![with-and-without-nativebase](./img/with-and-without-nativebase.jpg)</center>

Do you still have a question **Why NativeBase**?

If yes then go ahead and watch this magic.




## Magic of NativeBase
<center>[![magic](./img/magic.png)](http://nativebase.io/docs/v0.2.1/assets/img/magic-with-nativebase-020.mp4)</center>

<i>Click to watch the magic</i>



## Get Started

To have NativeBase components running onto your native apps, all you need to do is create a fresh [React Native](https://github.com/facebook/react-native) project and install the [NativeBase](http://nativebase.io/) command line tools.

```
react-native init AwesomeNativeBase

cd AwesomeNativeBase

npm install
```

Include NativeBase into your React Native project.
```
npm install native-base --save
```

Now you are ready to get going with NativeBase. [Read More. . .](http://nativebase.io/documentation)




## Components

[NativeBase](http://nativebase.io/) is made from effective building blocks referred to as components. The Components are constructed in pure [React Native](https://github.com/facebook/react-native) platform along with some JavaScript functionality with rich set of customisable properties. These components allow you to quickly build the perfect interface. [Read More. . .](http://nativebase.io/documentation)

#### [**Live Demo**](http://nativebase.io/components)




## [Native Starter Kit](https://github.com/start-react/native-starter-kit)

A simple starter project for [React Native](https://github.com/facebook/react-native) + [NativeBase](http://nativebase.io/) + [Redux](http://redux.js.org/) + [CodePush](https://github.com/Microsoft/react-native-code-push) + [React Native Navigator](https://facebook.github.io/react-native/docs/navigator.html) apps on iOS and Android.

No need of reinventing the wheel. To have immediately something to continue building on, it would be best to start from some starter kit for getting React Native - based applications off the ground in a hurry.

This is a starter kit that you can install on the fly to get the basic plumping of React Native with NativeBase, Redux and CodePush.

[Take a look at the demo](https://github.com/start-react/native-starter-kit#screens)






## Featured Apps - Native Starter Pro
Having tried with the free version, [Native Starter Kit](https://github.com/start-react/native-starter-kit) and appreciate our product?

Get on the mobile fast track with [Native Starter Pro](http://strapmobile.com/native-starter-pro/), to build high-quality iOS and Android mobile apps. 

Based on [React Native](https://facebook.github.io/react-native/) and [NativeBase](http://nativebase.io/docs/v0.4.6/), Native Starter Pro is a beautifully designed, responsive iOS and Android app source code to quickly get started on your next project. 

Native Starter Pro is a flexible React Native theme, built using [NativeBase](http://nativebase.io/documentation) and [Redux](https://github.com/reactjs/react-redux) with fusion of [ES6](http://es6-features.org/#Constants) which is best suited for developing apps that makes use of ready-made tools. The theme has several widget areas that allows you to extend your theme functionality with plugins. 

Native Starter Pro includes following ready-to-use and highly customizable components :

-	Button with various shapes and themes
-	Textbox
-	Form Elements
-	List
-	Header
-	Footer
-	Drawer
-	Full fledged collection of Icons
-	Spinner:Animated loading indicators which are flexible in diverse size and color.
-	ProgressBar: To visualize the process of work.
-	Modal
-	Ready to use Email Template
-	Interactive design of Calendar with fast swiping feature.
-	Scroll between the tabs
-	Responsive Navigator
-	Chat Messenger
-	Ready to use screens
-	Easy theme customization
-	[Read More](http://strapmobile.com/docs/native-starter-pro/v3.0/)

**Quick links to Native Starter Pro**

-	*[Native Starter Pro Features](http://strapmobile.com/docs/native-starter-pro/v3.0/overview/whats-new-in-v3-0)*
-	*[Native Starter Pro Components](http://strapmobile.com/docs/native-starter-pro/v3.0/components)*
-	*[Native Starter Pro's App Generator](http://strapmobile.com/customizer/#/color)*
-	*[Native Starter Pro Releases](http://strapmobile.com/native-starter-pro-releases/)*




## Quick Links to NativeBase

*	[NativeBase on Twitter](https://twitter.com/NativeBaseIO)
*	[NativeBase Blog](https://medium.com/nativebase-io-blog)
*	[NativeBase Documentation](http://nativebase.io/documentation)




## Documentation

Go through [NativeBase Docs](http://nativebase.io/documentation) to play with NativeBase.




## Website
[http://nativebase.io/](http://nativebase.io/)
